@@ -21,37 +21,39 @@
 
 #include "FortranMagics.h"
 
-#include "Coastlines.h"
-#include "LegendVisitor.h"
-#include "MagicsGlobal.h"
-#include "RootSceneNode.h"
-#include "SceneNode.h"
-#include "TextVisitor.h"
-#include "Timer.h"
-#include "ViewNode.h"
-#include "VisualAction.h"
-#include "GribDecoder.h"
 #include "Axis.h"
 #include "BoxPlotDecoder.h"
 #include "BoxPlotVisualiser.h"
+#include "Coastlines.h"
+#include "CompatibilityHelper.h"
 #include "Contour.h"
 #include "GeoPointsDecoder.h"
 #include "GraphPlotting.h"
+#include "GribDecoder.h"
 #include "ImportAction.h"
 #include "ImportObjectHandler.h"
 #include "ImportPlot.h"
 #include "InputMatrix.h"
+#include "LegendVisitor.h"
+#include "MagicsGlobal.h"
 #include "MapGenDecoder.h"
 #include "MetaData.h"
+#include "RootSceneNode.h"
+#include "SceneNode.h"
 #include "SimplePolylineInput.h"
 #include "SimplePolylineVisualiser.h"
 #include "SymbolInput.h"
 #include "SymbolPlotting.h"
 #include "TaylorGrid.h"
+#include "TextVisitor.h"
+#include "Timer.h"
 #include "TitleTemplate.h"
 #include "UserPoint.h"
+#include "ViewNode.h"
+#include "VisualAction.h"
 #include "Wind.h"
 #include "XYList.h"
+#include "MagicsGlobal.h"
 
 #ifdef HAVE_NETCDF
 #include "NetcdfDecoder.h"
@@ -70,6 +72,7 @@ FortranMagics::FortranMagics() :
     drivers_(0),
     output_(0),
     action_(0),
+    root_(0),
     empty_(true),
     gribindex_(0),
     legend_todo_(false),
@@ -79,24 +82,47 @@ FortranMagics::FortranMagics() :
     axisContainer_(0)
 
 {
-    ASSERT(singleton_ == 0);
-    singleton_ = this;
+    reset();
 }
 
 FortranMagics::~FortranMagics() {
-    if (drivers_)
-        delete drivers_;
-    //	if ( root_ ) delete root_;
-    if (output_)
-        delete output_;
-    singleton_ = 0;
+    reset();
+}
 
-    /*
-    ParameterManager::release();
-    TitleTemplate::release();
+void FortranMagics::reset() {
+    delete drivers_;
+    drivers_ = 0;
 
-    GribDecoder::releaseContext();
-    */
+    delete output_;
+    output_ = 0;
+
+    delete root_;
+    root_ = 0;
+
+    empty_            = true;
+    gribindex_        = 0;
+    legend_todo_      = false;
+    symbolinput_todo_ = false;
+    matrixinput_todo_ = false;
+    polyinput_todo_   = false;
+
+
+    while (actions_.size()) {
+        actions_.pop();
+    }
+
+    // TODO: clear memory
+    texts_.clear();
+    legends_.clear();
+    later_.clear();
+    while (axis_.size()) {
+        axis_.pop();
+    }
+
+
+    ParameterManager::reset();
+    Layout::reset();
+    CompatibilityHelper::resetAll();
 }
 
 /*!
@@ -108,7 +134,11 @@ void FortranMagics::print(ostream& out) const {
 }
 
 void FortranMagics::popen() {
+    reset();
+
     MagLog::info() << "popen()" << endl;
+
+
     if (getEnvVariable("MAGPLUS_QUIET").empty() && !MagicsGlobal::silent()) {
         MagLog::userInfo() << "----------------------------------------------------"
                               "--------------\n";
@@ -138,44 +168,34 @@ void FortranMagics::popen() {
   Here is where the real magics is happen. Everything is dispatched, followed
   by a comprehensive clean-up.
 */
-int FortranMagics::pclose(bool catch_exceptions) {
+void FortranMagics::pclose() {
     MagLog::info() << "pclose()" << endl;
-    singleton_ = 0;
-    try {
-        if (!empty_) {
-            finish();
-            dispatch();
-        }
 
-        if (root_ && drivers_) {
-            BasicGraphicsObject* object = root_->close();
-            if (object) {
-                /***   Start clean-up  ***/
-                drivers_->dispatch(object);
-                drivers_->closeDrivers();
-                drivers_->clear();
+    if (!empty_) {
+        finish();
+        dispatch();
+    }
 
-                //cout << "deleting object" << endl;
-                delete root_;
-                delete drivers_;
-                delete output_;
+    if (root_ && drivers_) {
+        BasicGraphicsObject* object = root_->close();
+        if (object) {
+            /***   Start clean-up  ***/
+            drivers_->dispatch(object);
+            drivers_->closeDrivers();
 
-                drivers_ = 0;
-                root_    = 0;
-                output_  = 0;
-            }
+            delete root_;
+            delete drivers_;
+            delete output_;
+
+            drivers_ = 0;
+            root_    = 0;
+            output_  = 0;
         }
     }
-    catch (MagicsException& e) {
-        MagLog::error() << "Errors reported:" << e.what() << " - No plot produced  " << endl;
-        MagLog::error().flush();
 
-        if(!catch_exceptions) {
-            throw;
-        }
+    ParameterManager::reset();
+    Layout::reset();
 
-        return -1;
-    }
 
     // the Magics log messages are not broadcast until the next log event -
     // therefore, the last log message will not be broadcast. We fix that by
@@ -184,12 +204,6 @@ int FortranMagics::pclose(bool catch_exceptions) {
     // scenes.
     MagLog::info().flush();
 
-    // We reset all the parameters to their default,
-    // then a consecutive call to popen will not be affected by the current
-    // values.
-    ParameterManager::reset();
-
-    Layout::reset();
 
     if (getEnvVariable("MAGPLUS_QUIET").empty() && !MagicsGlobal::silent()) {
         MagLog::userInfo() << "----------------------------------------------------"
@@ -201,8 +215,6 @@ int FortranMagics::pclose(bool catch_exceptions) {
         MagLog::userInfo() << "----------------------------------------------------"
                               "--------------\n";
     }
-    singleton_ = 0;
-    return 0;
 }
 
 void FortranMagics::drivers() {
@@ -376,10 +388,10 @@ void FortranMagics::actions() {
         Action action = actions_.top();
         (this->*action)();
         actions_.pop();
-        
+
         empty_ = false;
     }
-   
+
 }
 
 void FortranMagics::pcoast() {
@@ -433,7 +445,7 @@ void FortranMagics::ptest() {
 void FortranMagics::finish() {
     if (!empty_) {
         actions();  // The flag to force the generation of the plot has been set!
-        
+
     }
 
     if (!axisContainer_)
@@ -545,11 +557,14 @@ const char* FortranMagics::detect(const string& data, const string& dim) {
     DimensionGuess json(data);
 
     NetcdfGuess guesser;
-    static string empty, result;
+    static string empty;
+    static string result;
+
     auto checks = guesser.guess_.find(dim);
-    if (checks == guesser.guess_.end())
+    if (checks == guesser.guess_.end()) {
         return empty.c_str();
-    result = "";
+    }
+    result.clear();
 
     for (auto check = checks->second.begin(); check != checks->second.end(); ++check) {
         vector<string> values = check->second;
@@ -592,6 +607,8 @@ const char* FortranMagics::metanetcdf() {
     static string temp;
     temp = out.str();
     return temp.c_str();
+#else
+    return 0;
 #endif
 }
 
@@ -891,10 +908,9 @@ void FortranMagics::epsinput() {
 #include "MetgramGraph.h"
 void FortranMagics::metgraph() {
     actions();
-    if (!action_) {
-        MagLog::error() << "epscloud -> No data defined " << endl;
-        exit(1);
-    }
+
+    ASSERT(action_);
+
     MetgramGraph* graph = new MetgramGraph();
 
     action_->visdef(graph);
@@ -902,20 +918,18 @@ void FortranMagics::metgraph() {
 
 void FortranMagics::epscloud() {
     actions();
-    if (!action_) {
-        MagLog::error() << "epscloud -> No data defined " << endl;
-        exit(1);
-    }
+
+    ASSERT(action_);
+
     EpsCloud* epscloud = new EpsCloud();
 
     action_->visdef(epscloud);
 }
 void FortranMagics::epsplumes() {
     actions();
-    if (!action_) {
-        MagLog::error() << "epsplumes -> No data defined " << endl;
-        exit(1);
-    }
+
+    ASSERT(action_);
+
     EpsPlume* plumes = new EpsPlume();
 
     action_->visdef(plumes);
@@ -923,40 +937,36 @@ void FortranMagics::epsplumes() {
 
 void FortranMagics::epsgraph() {
     actions();
-    if (!action_) {
-        MagLog::error() << "epscloud -> No data defined " << endl;
-        exit(1);
-    }
+
+    ASSERT(action_);
+
     EpsGraph* epsgraph = new EpsGraph();
     action_->visdef(epsgraph);
 }
 
 void FortranMagics::epslight() {
     actions();
-    if (!action_) {
-        MagLog::error() << "epslight-> No data defined " << endl;
-        exit(1);
-    }
+
+    ASSERT(action_);
+
     EpsLight* epslight = new EpsLight();
     action_->visdef(epslight);
 }
 
 void FortranMagics::epswave() {
     actions();
-    if (!action_) {
-        MagLog::error() << "epscloud -> No data defined " << endl;
-        exit(1);
-    }
+
+    ASSERT(action_);
+
     EpsWave* eps = new EpsWave();
     action_->visdef(eps);
 }
 
 void FortranMagics::epswind() {
     actions();
-    if (!action_) {
-        MagLog::error() << "epscloud -> No data defined " << endl;
-        exit(1);
-    }
+
+    ASSERT(action_);
+
     EpsWind* epswind = new EpsWind();
     action_->visdef(epswind);
 }
@@ -967,17 +977,16 @@ void FortranMagics::epsbar() {
 }
 void FortranMagics::epsshading() {
     actions();
-    if (!action_) {
-        MagLog::error() << "epscloud -> No data defined " << endl;
-        exit(1);
-    }
+
+    ASSERT(action_);
+
     EpsShade* eps = new EpsShade();
     action_->visdef(eps);
 }
 
 void FortranMagics::paxis() {
-   
-   
+
+
     try {
         string orientation;
 
@@ -988,21 +997,25 @@ void FortranMagics::paxis() {
             MagLog::dev() << *vaxis << "\n";
             if (axisContainer_)
                 axisContainer_->push_back(vaxis);
-            else 
+            else
                 axis_.push(vaxis);
-            
+
         }
         else {
             Axis* haxis = new HorizontalAxis();
             MagLog::dev() << *haxis << "\n";
             if (axisContainer_)
                 axisContainer_->push_back(haxis);
-            else 
+            else
                 axis_.push(haxis);
-            
+
         }
     }
     catch (MagicsException& e) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
+
         MagLog::error() << e << "\n";
     }
     empty_ = false;  // Force the generation of the plot!
@@ -1064,5 +1077,7 @@ void FortranMagics::pboxplot() {
     action_->visdef(plot);
 }
 
-FortranMagics* FortranMagics::singleton_ = 0;
-MagicsGlobal* MagicsGlobal::singleton_   = 0;
+FortranMagics& FortranMagics::instance() {
+    static FortranMagics instance_;
+    return instance_;
+}
