@@ -344,43 +344,43 @@ Layout* LayoutVisitor::mainLayout() const {
 
 Justification TopAxisVisitor::justificationTickLabel(const string& orientation) {
     // horizontal == parallel
-    return (magCompare(orientation, "vertical")) ? MLEFT : MCENTRE;
+    return (magCompare(orientation, "vertical")) ? Justification::LEFT : Justification::CENTRE;
 }
 
 Justification BottomAxisVisitor::justificationTickLabel(const string& orientation) {
     // horizontal == parallel
-    return (magCompare(orientation, "vertical")) ? MRIGHT : MCENTRE;
+    return (magCompare(orientation, "vertical")) ? Justification::RIGHT : Justification::CENTRE;
 }
 
 Justification LeftAxisVisitor::justificationTickLabel(const string& orientation) {
     // vertical == parallel
-    return (magCompare(orientation, "horizontal")) ? MRIGHT : MCENTRE;
+    return (magCompare(orientation, "horizontal")) ? Justification::RIGHT : Justification::CENTRE;
 }
 Justification RightAxisVisitor::justificationTickLabel(const string& orientation) {
     // vertical == parallel
-    return (magCompare(orientation, "horizontal")) ? MLEFT : MCENTRE;
+    return (magCompare(orientation, "horizontal")) ? Justification::LEFT : Justification::CENTRE;
 }
 Justification VerticalAxisVisitor::justificationTickLabel(const string& orientation) {
-    return MCENTRE;
+    return Justification::CENTRE;
 }
 
 VerticalAlign TopAxisVisitor::textAlignment(const string& orientation) {
     // horizontal == parallel
-    return (magCompare(orientation, "vertical")) ? MHALF : MTOP;
+    return (magCompare(orientation, "vertical")) ? VerticalAlign::HALF : VerticalAlign::TOP;
 }
 
 VerticalAlign BottomAxisVisitor::textAlignment(const string& orientation) {
     // horizontal == parallel
-    return (magCompare(orientation, "vertical")) ? MHALF : MBOTTOM;
+    return (magCompare(orientation, "vertical")) ? VerticalAlign::HALF : VerticalAlign::BOTTOM;
 }
 
 VerticalAlign LeftAxisVisitor::textAlignment(const string& orientation) {
     // vertical == parallel
-    return (magCompare(orientation, "horizontal")) ? MHALF : MBOTTOM;
+    return (magCompare(orientation, "horizontal")) ? VerticalAlign::HALF : VerticalAlign::BOTTOM;
 }
 VerticalAlign RightAxisVisitor::textAlignment(const string& orientation) {
     // vertical == parallel
-    return (magCompare(orientation, "horizontal")) ? MHALF : MTOP;
+    return (magCompare(orientation, "horizontal")) ? VerticalAlign::HALF : VerticalAlign::TOP;
 }
 
 double RightAxisVisitor::percentX(double percent) {
@@ -417,4 +417,4 @@ double TopAxisVisitor::percentX(double percent) {
 double TopAxisVisitor::percentY(double percent) {
     double pos = ((current_->ymax_ - current_->ymin_) / 100) * percent;
     return current_->ymin_ + pos;
-}
\ No newline at end of file
+}
