@@ -26,11 +26,8 @@
 
 #include "MagException.h"
 #include "magics.h"
-#include "magics_windef.h"
-#ifdef MAGICS_ON_WINDOWS
-#include <iterator>
-#endif
-#include <ProjP.h>
+
+#include "ProjP.h"
 
 namespace magics {
 
@@ -112,10 +109,9 @@ public:
     virtual bool hasMissingValues() const { return false; }
 
     virtual vector<double>& columnsAxis() const = 0;
-    virtual void print(ostream& out) const {
-        out << "No Print implemented for this MatrixHandler"
-            << "\n";
-    }
+    virtual void print(ostream& out) const      = 0;
+
+
     //! Overloaded << operator to call print().
     friend ostream& operator<<(ostream& s, const AbstractMatrix& p) {
         p.print(s);
@@ -142,12 +138,12 @@ public:
     OutOfRange(double r, double c) {
         ostringstream s;
         s << "Out of Range: Cannot access [" << r << ", " << c << "]" << ends;
-        what_ = s.str();
+        reason(s.str());
     }
     OutOfRange(double x) {
         ostringstream s;
         s << "Out of Range: Cannot access [" << x << "]" << ends;
-        what_ = s.str();
+        reason(s.str());
     }
 };
 
@@ -182,7 +178,7 @@ public:
     Matrix* clone() { return new Matrix(); }
     void set(const XmlNode&) {}
 
-    MatrixHandler* getReady(const Transformation&) const;
+    MatrixHandler* getReady(const Transformation&) const override;
 
     Matrix(int rows, int columns, double val) :
         rows_(rows), columns_(columns), missing_(DBL_MIN), akima_(false), min_(DBL_MAX), max_(DBL_MIN) {
@@ -201,21 +197,21 @@ public:
         columnsAxis_.reserve(columns);
     }
 
-    double min() const;
-    double max() const;
+    double min() const override;
+    double max() const override;
     void min(double m) { min_ = m; }
     void max(double m) { max_ = m; }
 
-    virtual ~Matrix() {}
+    virtual ~Matrix() override {}
 
-    double width() const { return regular_column(columns_ - 1) - regular_column(0); }
-    double height() const { return regular_row(rows_ - 1) - regular_row(0); }
+    double width() const override { return regular_column(columns_ - 1) - regular_column(0); }
+    double height() const override { return regular_row(rows_ - 1) - regular_row(0); }
 
-    int rows() const { return rows_; }
-    int columns() const { return columns_; }
+    int rows() const override { return rows_; }
+    int columns() const override { return columns_; }
 
-    double regular_row(int i) const { return rowsAxis_[i]; }
-    double row(int i, int) const { return regular_row(i); }
+    double regular_row(int i) const override { return rowsAxis_[i]; }
+    double row(int i, int) const override { return regular_row(i); }
 
     void release() {
         rows_    = 0;
@@ -228,11 +224,11 @@ public:
         this->resize(0);
     }
 
-    double regular_column(int j) const { return columnsAxis_[j]; }
-    double column(int, int j) const { return columnsAxis_[j]; }
+    double regular_column(int j) const override { return columnsAxis_[j]; }
+    double column(int, int j) const override { return columnsAxis_[j]; }
 
     void missing(double missing) { missing_ = missing; }
-    double missing() const { return missing_; }
+    double missing() const override { return missing_; }
 
     void setRowsAxis(const vector<double>& axis) {
         int ind = 0;
@@ -267,32 +263,32 @@ public:
         columns_ = ind;
     }
 
-    double interpolate(double r, double c) const;
-    double nearest(double i, double j) const {
+    double interpolate(double r, double c) const override;
+    double nearest(double i, double j) const override {
         double d1, d2;
         return nearest(i, j, d1, d2);
     }
-    double nearest(double i, double j, double& iOut, double& jOut) const;
+    double nearest(double i, double j, double& iOut, double& jOut) const override;
     pair<double, double> nearest_value(double i, double j, double& iOut, double& jOut) const;
     virtual int nearest_index(double i, double j, double& iOut, double& jOut) const;
     void multiply(double factor);
     void plus(double offset);
 
-    virtual int firstRow() const { return 0; }
-    virtual int nextRow(int i, int f) const {
+    virtual int firstRow() const override { return 0; }
+    virtual int nextRow(int i, int f) const override {
         i += f;
         return (i < rows_) ? i : -1;
     }
 
-    virtual int firstColumn() const { return 0; }
-    virtual int nextColumn(int j, int f) const {
+    virtual int firstColumn() const override { return 0; }
+    virtual int nextColumn(int j, int f) const override {
         j += f;
         return (j < rows_) ? j : -1;
     }
 
-    double operator()(int row, int column) const;
+    double operator()(int row, int column) const override;
 
-    double YResolution() const {
+    double YResolution() const override {
         magvector<double> diff;
         diff.reserve(rowsAxis_.size());
         std::adjacent_difference(rowsAxis_.begin(), rowsAxis_.end(), back_inserter(diff));
@@ -300,7 +296,7 @@ public:
         // MagLog::dev() << "Matrix::YResolution()--->" << resol << "\n";
         return resol;
     }
-    double XResolution() const {
+    double XResolution() const override {
         magvector<double> diff;
         diff.reserve(columnsAxis_.size());
         std::adjacent_difference(columnsAxis_.begin(), columnsAxis_.end(), back_inserter(diff));
@@ -308,42 +304,42 @@ public:
         // MagLog::dev() << "Matrix::XResolution()--->" << resol << "\n";
         return resol;
     }
+    vector<double>& rowsAxis() const override { return rowsAxis_; }
+    vector<double>& columnsAxis() const override { return columnsAxis_; }
 
-    vector<double>& rowsAxis() const { return rowsAxis_; }
-    vector<double>& columnsAxis() const { return columnsAxis_; }
+    double minX() const override { return std::min(columnsAxis_.front(), columnsAxis_.back()); }
+    double minY() const override { return std::min(rowsAxis_.front(), rowsAxis_.back()); }
+    double maxX() const override { return std::max(columnsAxis_.front(), columnsAxis_.back()); }
+    double maxY() const override { return std::max(rowsAxis_.front(), rowsAxis_.back()); }
+    double left() const override { return std::min(columnsAxis_.front(), columnsAxis_.back()); }
+    double bottom() const override { return std::min(rowsAxis_.front(), rowsAxis_.back()); }
+    double right() const override { return std::max(columnsAxis_.front(), columnsAxis_.back()); }
+    double top() const override { return std::max(rowsAxis_.front(), rowsAxis_.back()); }
 
-    double minX() const { return std::min(columnsAxis_.front(), columnsAxis_.back()); }
-    double minY() const { return std::min(rowsAxis_.front(), rowsAxis_.back()); }
-    double maxX() const { return std::max(columnsAxis_.front(), columnsAxis_.back()); }
-    double maxY() const { return std::max(rowsAxis_.front(), rowsAxis_.back()); }
-    double left() const { return std::min(columnsAxis_.front(), columnsAxis_.back()); }
-    double bottom() const { return std::min(rowsAxis_.front(), rowsAxis_.back()); }
-    double right() const { return std::max(columnsAxis_.front(), columnsAxis_.back()); }
-    double top() const { return std::max(rowsAxis_.front(), rowsAxis_.back()); }
 
-    double x(double x, double) const { return x; }
-    double y(double, double y) const { return y; }
+    double x(double x, double) const override { return x; }
+    double y(double, double y) const override { return y; }
 
-    virtual int rowIndex(double r) const { return row_ind(r); }
-    virtual int columnIndex(double c) const { return column_ind(c); }
-    virtual bool akimaEnable() const { return akima_; }
+    virtual int rowIndex(double r) const override { return row_ind(r); }
+    virtual int columnIndex(double c) const override { return column_ind(c); }
+    virtual bool akimaEnable() const override { return akima_; }
     void akimaEnabled() { akima_ = true; }
     void akimaDisabled() { akima_ = false; }
-    virtual void boundRow(double r, double& row1, int& index1, double& row2, int& index2) const {
+    virtual void boundRow(double r, double& row1, int& index1, double& row2, int& index2) const override{
         index1 = this->lowerRow(r);
         row1   = this->regular_row(index1);
         index2 = this->upperRow(r);
         row2   = this->regular_row(index2);
     }
 
-    virtual void boundColumn(double r, double& column1, int& index1, double& column2, int& index2) const {
+    virtual void boundColumn(double r, double& column1, int& index1, double& column2, int& index2) const override {
         index1  = this->lowerColumn(r);
         column1 = this->regular_column(index1);
         index2  = this->upperColumn(r);
         column2 = this->regular_column(index2);
     }
 
-    int lowerRow(double r) const {
+    int lowerRow(double r) const override {
         int last = -1;
         for (map<double, int>::const_iterator i = rowsMap_.begin(); i != rowsMap_.end(); ++i) {
             if (i->first > r) {
@@ -353,7 +349,7 @@ public:
         }
         return last;
     }
-    int lowerColumn(double c) const {
+    int lowerColumn(double c) const override {
         int last = -1;
         for (map<double, int>::const_iterator i = columnsMap_.begin(); i != columnsMap_.end(); ++i) {
             if (i->first > c)
@@ -362,6 +358,7 @@ public:
         }
         return last;
     }
+
     int upperRow(double r) const {
         for (map<double, int>::const_iterator i = rowsMap_.begin(); i != rowsMap_.end(); ++i) {
             if (i->first >= r) {
@@ -378,6 +375,7 @@ public:
         return -1;
     }
 
+
     map<double, map<double, pair<double, double> > > index_;
     map<double, int> yIndex_;  // lat--> index
     vector<InfoIndex> xIndex_;
@@ -386,7 +384,7 @@ public:
 protected:
     //! Method to print string about this class on to a stream of type ostream
     //! (virtual).
-    virtual void print(ostream& out) const {
+    virtual void print(ostream& out) const override {
         out << "Matrix<P>[";
         out << "rowsAxis=" << rowsAxis_;
         out << ", columnsAxis=" << columnsAxis_;
@@ -446,7 +444,9 @@ class ProjectedMatrix : public Matrix {
 public:
     ProjectedMatrix(int rows, int columns);
 
-    MatrixHandler* getReady(const Transformation& transformation) const { return Matrix::getReady(transformation); }
+    MatrixHandler* getReady(const Transformation& transformation) const override {
+        return Matrix::getReady(transformation);
+    }
     void getReady();  // Prepare the matrix ...
 
     vector<double>& values() const { return values_; }
@@ -476,7 +476,7 @@ protected:
 class Proj4Matrix : public Matrix {
 public:
     Proj4Matrix(const string& proj) : Matrix(), projHelper_(proj), proj_(proj) {}
-    MatrixHandler* getReady(const Transformation&) const;
+    MatrixHandler* getReady(const Transformation&) const override;
 
 protected:
     LatLonProjP projHelper_;
@@ -487,12 +487,12 @@ class RotatedMatrix : public Matrix {
 public:
     RotatedMatrix() : Matrix(), helper_(0) {}
     RotatedMatrix(int rows, int columns, double lat, double lon);
-    MatrixHandler* getReady(const Transformation&) const;
+    MatrixHandler* getReady(const Transformation&) const override;
     void setSouthPole(double lat, double lon) {
         southPoleLat_ = lat;
         southPoleLon_ = lon;
     }
-    int nearest_index(double i, double j, double& iOut, double& jOut) const;
+    int nearest_index(double i, double j, double& iOut, double& jOut) const override;
 
 protected:
     RotatedMatrixHandler* helper_;
