@@ -38,11 +38,13 @@ Transformation::Transformation() :
     zoomLevel_(0) {
     userEnveloppe_ = new magics::Polyline();
     PCEnveloppe_   = new magics::Polyline();
+    PCExtendedEnveloppe_   = new magics::Polyline();
 }
 
 Transformation::~Transformation() {
     delete userEnveloppe_;
     delete PCEnveloppe_;
+    delete PCExtendedEnveloppe_;
 }
 
 void Transformation::print(ostream& out) const {
@@ -189,12 +191,7 @@ void Transformation::thin(MatrixHandler& matrix, double x, double y, vector<User
 }
 
 ViewFilter::ViewFilter(double xmin, double xmax, double ymin, double ymax, double xres, double yres) :
-    xmin_(xmin),
-    xmax_(xmax),
-    ymin_(ymin),
-    ymax_(ymax),
-    xres_(xres),
-    yres_(yres) {
+    xmin_(xmin), xmax_(xmax), ymin_(ymin), ymax_(ymax), xres_(xres), yres_(yres) {
     xdim_ = (int)(xmax_ - xmin_) / xres_;
     ydim_ = (int)(ymax_ - ymin_) / yres_;
 
@@ -311,7 +308,7 @@ void Transformation::operator()(const magics::Polyline& from, BasicGraphicsObjec
 }
 
 void Transformation::operator()(const magics::Polyline& from, vector<magics::Polyline*>& out) const {
-    assert(false);
+    ASSERT(false);
     if (from.empty())
         return;
 
@@ -347,6 +344,7 @@ bool Transformation::in(const UserPoint& point) const {
 }
 
 bool Transformation::in(const PaperPoint& point) const {
+
     if (PCEnveloppe_->empty()) {
         PCEnveloppe_->push_back(PaperPoint(getMinPCX(), getMinPCY()));
         PCEnveloppe_->push_back(PaperPoint(getMinPCX(), getMaxPCY()));
@@ -354,10 +352,21 @@ bool Transformation::in(const PaperPoint& point) const {
         PCEnveloppe_->push_back(PaperPoint(getMaxPCX(), getMinPCY()));
         PCEnveloppe_->push_back(PaperPoint(getMinPCX(), getMinPCY()));
     }
-
     return PCEnveloppe_->within(point);
 }
 
+bool Transformation::inExtended(const PaperPoint& point) const {
+
+    if (PCExtendedEnveloppe_->empty()) {
+        PCExtendedEnveloppe_->push_back(PaperPoint(getExtendedMinPCX(), getExtendedMinPCY()));
+        PCExtendedEnveloppe_->push_back(PaperPoint(getExtendedMinPCX(), getExtendedMaxPCY()));
+        PCExtendedEnveloppe_->push_back(PaperPoint(getExtendedMaxPCX(), getExtendedMaxPCY()));
+        PCExtendedEnveloppe_->push_back(PaperPoint(getExtendedMaxPCX(), getExtendedMinPCY()));
+        PCExtendedEnveloppe_->push_back(PaperPoint(getExtendedMinPCX(), getExtendedMinPCY()));
+    }
+    return PCExtendedEnveloppe_->within(point);
+}
+
 bool Transformation::in(double x, double y) const {
     fast_reproject(x, y);
     if (x <= askedxmin_)
@@ -475,10 +484,11 @@ void Transformation::thin(double step, PaperPoint& origin, vector<pair<double, d
     Timer timer("thinning", "");
 
     vector<std::pair<double, double> > xypoints;
-    double minx = getMinPCX();
-    double maxx = getMaxPCX();
-    double miny = getMinPCY();
-    double maxy = getMaxPCY();
+    double minx = getExtendedMinPCX();
+    double maxx = getExtendedMaxPCX();
+    double miny = getExtendedMinPCY();
+    double maxy = getExtendedMaxPCY();
+
 
     std::set<double> xl, yl;
 
