@@ -22,7 +22,10 @@
 #include "XmlReader.h"
 #include "MagException.h"
 #include "MagLog.h"
+#include "MagicsGlobal.h"
 #include "expat.h"
+
+
 using namespace magics;
 
 XmlReader::XmlReader(bool tag) : dataAsTag_(tag) {}
@@ -71,17 +74,6 @@ static void XMLCALL dataHandler(void* data, const char* value, int len) {
 }
 
 
-static int externalEntityRefHandler(XML_Parser,  //	 parser,
-                                    const XML_Char* context, const XML_Char* base, const XML_Char* systemID,
-                                    const XML_Char* publicID) {
-    // MagLog::dev()<< "context--->" << context << endl;
-    // MagLog::dev()<< "base--->" << base << endl;
-    // MagLog::dev()<< "systemID--->" << systemID << endl;
-    // MagLog::dev()<< "publicID--->" << publicID << endl;
-    return 0;
-}
-
-
 void XmlReader::newElement(const string& name, const map<string, string>& def) {
     // Here we create a XmlNode you put in the tree...
     XmlNode* parent = tree_->getParent(name);
@@ -128,6 +120,9 @@ void XmlReader::interpret(const string& xml, XmlTree* tree) {
     FILE* in = fopen(xml.c_str(), "r");
 
     if (!in) {
+        if (MagicsGlobal::strict()) {
+            throw CannotOpenFile(xml);
+        }
         MagLog::dev() << "XmlDecoder: can not open file " << xml << endl;
         MagLog::error() << "XmlDecoder: can not open file " << xml << endl;
         return;
