@@ -22,20 +22,24 @@
 
 #include <limits>
 
-#include "Factory.h"
-#include "magics_windef.h"
-#ifndef MAGICS_ON_WINDOWS
-#include <unistd.h>
-#else
-#include <fcntl.h>
-#endif
-
 #include <cerrno>
 
+#if defined(HAVE_METVIEW) && !defined(MAGICS_ON_WINDOWS)
+// for readlink()
+#include <unistd.h>
+#endif
+
+
+#include "Factory.h"
+#include "magics.h"
+
+
+#include <eccodes.h>
 #include "AnimationRules.h"
 #include "GribInterpretor.h"
 #include "MagDateTime.h"
 #include "MagJSon.h"
+#include "MagicsGlobal.h"
 #include "MetaData.h"
 #include "TextVisitor.h"
 #include "Timer.h"
@@ -43,7 +47,6 @@
 #include "Transformation.h"
 #include "VisualAction.h"
 #include "XmlReader.h"
-#include "eccodes.h"
 
 using namespace magics;
 
@@ -119,6 +122,7 @@ void GribDecoder::set(const GribLoop& loop, int index) {
     interpolation_method_ = loop.interpolation_method_;
     missing_fill_count_   = loop.missing_fill_count_;
     regular_resolution_   = loop.regular_resolution_;
+    id_                   = loop.id_;
     wind_mode_            = unique_ptr<WindMode>(loop.wind_mode_->clone());
     internalIndex_        = index;
 }
@@ -162,6 +166,7 @@ long GribDecoder::getLong(const string& key, bool warnIfKeyAbsent) const {
     if (lk != lKeys_.end()) {
         return lk->second;
     }
+    ASSERT(current_handle_);
     int err = grib_get_long(current_handle_, key.c_str(), &val);
     if (err) {
         if (warnIfKeyAbsent) {
@@ -185,6 +190,7 @@ string GribDecoder::getstring(const string& key, bool warnIfKeyAbsent, bool cach
     char val[1024];
     size_t length = 1024;
 
+    ASSERT(current_handle_);
     int err = grib_get_string(current_handle_, key.c_str(), val, &length);
 
     if (err) {
@@ -210,9 +216,9 @@ string GribDecoder::getString(const string& key, bool warnIfKeyAbsent) const {
     string value;
     // otherwise we build a name...
 
-    current_handle_   = field_;
-    GribDecoder* grib = const_cast<GribDecoder*>(this);
-    value             = getstring(key, warnIfKeyAbsent, false);
+    current_handle_ = field_;
+    // GribDecoder* grib = const_cast<GribDecoder*>(this);
+    value = getstring(key, warnIfKeyAbsent, false);
 
     if (component2_) {
         current_handle_ = component2_;
@@ -234,6 +240,7 @@ double GribDecoder::getDouble(const string& key, bool warnIfKeyAbsent) const {
         return dk->second;
     }
     double val;
+    ASSERT(current_handle_);
     int err = grib_get_double(current_handle_, key.c_str(), &val);
     if (err) {
         if (warnIfKeyAbsent) {
@@ -246,9 +253,7 @@ double GribDecoder::getDouble(const string& key, bool warnIfKeyAbsent) const {
 }
 
 void GribDecoder::setDouble(const string& key, double val) const {
-    if (!valid_ || !current_handle_ )
-        MagLog::warning() << "ecCodes: cannot find data to set the key [" << key << "] \n";
-        
+    ASSERT(current_handle_);
     int err = grib_set_double(current_handle_, key.c_str(), val);
     if (err) {
         MagLog::warning() << "ecCodes: cannot find key [" << key << "]  - " << grib_get_error_message(err) << "\n";
@@ -261,7 +266,7 @@ void GribDecoder::setDouble(const string& key, double val) const {
     }
 }
 
-const DateTime& GribDecoder::from() { 
+const DateTime& GribDecoder::from() {
     decode();
     return from_;
 
@@ -273,7 +278,7 @@ const DateTime& GribDecoder::to()
 }
 
 void GribDecoder::scale(const string& metadata, double& scaling, double& offset) {
-    assert(false);
+    ASSERT(false);
 }
 
 bool GribDecoder::isEarthOblate() const {
@@ -286,6 +291,7 @@ bool GribDecoder::isEarthOblate() const {
     return false;
 }
 
+
 Matrix* GribDecoder::colour(Matrix* matrix) {
     if (cHandle()) {
         colourComponent_ = matrix;
@@ -342,6 +348,9 @@ void GribDecoder::read() {
         interpretor_->scaling(*this, *matrix);
     }
     catch (NoFactoryException&) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         ostringstream msg;
         msg << "Grib Decoder - read: Representation [" << grid << "] not supported";
         MagLog::error() << msg.str() << endl;
@@ -366,8 +375,11 @@ void GribDecoder::read(const Transformation& transformation) {
         interpretor_->scaling(*this, *matrix);
     }
     catch (NoFactoryException&) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::error() << "Grib Decoder - read: Representation [" << grid << "] not supported.\n" << std::endl;
-        ;
+
         valid_ = false;
         throw MagicsException("Grib Decoder: Representation [] not supported.");
     }
@@ -445,6 +457,9 @@ void GribDecoder::decode2D() {
         interpretor_->keepOriginal(true);
     }
     catch (NoFactoryException&) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::warning() << "Grib Decoder: Vector cobination of representations [" << grid << "] not supported.\n"
                           << std::endl;
         ;
@@ -491,9 +506,11 @@ void GribDecoder::customisedPoints(const AutomaticThinningMethod& thinning, cons
         customisedPoints(transformation, points, xstep, ystep, 0);
     }
     catch (NoFactoryException&) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::error() << "Grib Decoder - customisedPoints: Representation [" << grid << "] not supported.\n"
                         << std::endl;
-        ;
         throw MagicsException("Grib Decoder: Representation [] not supported.");
     }
 }
@@ -513,11 +530,6 @@ grib_handle* GribDecoder::cHandle(string& name) {
     return colour_;
 }
 
-bool compare(const pair<double, double>& pt1, const pair<double, double>& pt2) {
-    if (pt1.second != pt2.second)
-        return false;
-    return pt1.second < pt2.second;
-}
 
 void GribDecoder::newPoint(const Transformation& transformation, double lat, double lon, double uc, double vc,
                            double cc, vector<CustomisedPoint*>& points, double grid) {
@@ -741,6 +753,7 @@ void GribDecoder::openThirdComponent() {
     colour_           = open(colour_, false);
 }
 
+
 grib_handle* GribEntryDecoder::open(grib_handle* handle, bool) {
     return handle;
 }
@@ -754,11 +767,12 @@ grib_handle* GribDecoder::open(grib_handle* grib, bool sendmsg) {
     FILE* file = fopen(file_name_.c_str(), "rb");
 
     if (!file) {
-        ostringstream error;
-        error << "file can not be opened [" << file_name_ << "] " << std::strerror(errno) << std::endl;
-        MagLog::broadcast();
+        if (MagicsGlobal::strict()) {
+            throw CannotOpenFile(file_name_);
+        }
+
         valid_ = false;
-        throw MagicsException(error.str());
+        MagLog::error() << "ERROR: unable to open file '" << file_name_ << "': " << MagicsException::syserror() << endl;
         return 0;
     }
 
@@ -817,6 +831,8 @@ grib_nearest* GribDecoder::nearest_point_handle(bool keep) {
 }
 
 bool GribDecoder::id(const string& id, const string& where) const {
+
+   
     if (id_.empty() && id.empty()) {
         return (verify(where));
     }
@@ -861,8 +877,8 @@ void GribDecoder::decodePoints() {
     int error;
 
     if (Data::dimension_ == 1) {
-        double scaling;
-        double offset;
+        double scaling    = 1;
+        double offset     = 0;
         const string grid = representation();
         double missing    = getDouble("missingValue");
         try {
@@ -872,8 +888,10 @@ void GribDecoder::decodePoints() {
             interpretor_->scaling(*this, scaling, offset);
         }
         catch (NoFactoryException&) {
+            if (MagicsGlobal::strict()) {
+                throw;
+            }
             MagLog::warning() << "Grib Decoder: Representation [" << grid << "] not supported.\n" << std::endl;
-            ;
             scaling = 1;
             offset  = 0;
         }
@@ -979,7 +997,7 @@ bool GribLoop::hasMore() {
         file_ = fopen(path_.c_str(), "r");
         if (!file_) {
             MagLog::error() << "file can not be opened [" << path_ << "] " << std::strerror(errno) << std::endl;
-            throw GribFileMagException(path_, 0);
+            throw CannotOpenFile(path_);
         }
     }
 
@@ -1137,16 +1155,21 @@ public:
         const long day  = grib_.getLong("date");
         const long hour = grib_.getLong("hour");
         const long mn   = grib_.getLong("minute");
-        MagDate part1   = MagDate(day);
-        MagTime part2   = MagTime(hour, mn, 0);
-        DateTime full(part1, part2);
+        try {
+            MagDate part1 = MagDate(day);
+            MagTime part2 = MagTime(hour, mn, 0);
+            DateTime full(part1, part2);
 
-        const long type = grib_.getLong("significanceOfReferenceTime", false);
-        if (type == 2) {  //     Verifying time of forecast
-            const long step = computeStep(grib_, "stepRange");
-            full            = full + (step * -1);
+            const long type = grib_.getLong("significanceOfReferenceTime", false);
+            if (type == 2) {  //     Verifying time of forecast
+                const long step = computeStep(grib_, "stepRange");
+                full            = full + (step * -1);
+            }
+            return full.tostring(format);
+        }
+        catch (MagicsException&) {
+            return "undef";
         }
-        return full.tostring(format);
     }
 
     string startDate(const XmlNode& node) {
@@ -1158,12 +1181,16 @@ public:
         const long mn   = grib_.getLong("minute");
         const long step = computeStep(grib_, "startStep");
 
-        MagDate part1 = MagDate(day);
-        MagTime part2 = MagTime(hour, mn, 0);
-        DateTime full(part1, part2);
-        full = full + step;
-
-        return full.tostring(format);
+        try {
+            MagDate part1 = MagDate(day);
+            MagTime part2 = MagTime(hour, mn, 0);
+            DateTime full(part1, part2);
+            full = full + step;
+            return full.tostring(format);
+        }
+        catch (MagicsException&) {
+            return "undef";
+        }
     }
 
     string validDate(const XmlNode& node) {
@@ -1174,16 +1201,19 @@ public:
         const long hour = grib_.getLong("hour");
         const long mn   = grib_.getLong("minute");
         const long step = computeStep(grib_, "stepRange");  // default is in hours. Set 'stepUnits' to change.
-
-        MagDate part1 = MagDate(day);
-        MagTime part2 = MagTime(hour, mn, 0);
-        DateTime full(part1, part2);
-        const long type = grib_.getLong("significanceOfReferenceTime", false);
-        if (type != 2) {  //     Verifying time of forecast
-            full = full + step;
+        try {
+            MagDate part1 = MagDate(day);
+            MagTime part2 = MagTime(hour, mn, 0);
+            DateTime full(part1, part2);
+            const long type = grib_.getLong("significanceOfReferenceTime", false);
+            if (type != 2) {  //     Verifying time of forecast
+                full = full + step;
+            }
+            return full.tostring(format);
+        }
+        catch (MagicsException&) {
+            return "undef";
         }
-
-        return full.tostring(format);
     }
 
     string dataDate(const XmlNode& node) {
@@ -1191,13 +1221,17 @@ public:
         string format  = node.getAttribute("format");
         if (format.empty())
             return tostring(day);
+        try {
+            // Otherwise format the date
+            MagDate part1 = MagDate(day);
+            MagTime part2 = MagTime(0, 0, 0);
 
-        // Otherwise format the date
-        MagDate part1 = MagDate(day);
-        MagTime part2 = MagTime(0, 0, 0);
-
-        DateTime full(part1, part2);
-        return full.tostring(format);
+            DateTime full(part1, part2);
+            return full.tostring(format);
+        }
+        catch (MagicsException&) {
+            return "undef";
+        }
     }
 
     string endDate(const XmlNode& node) {
@@ -1208,19 +1242,25 @@ public:
         const long hour = grib_.getLong("hour");
         const long mn   = grib_.getLong("minute");
         const long step = computeStep(grib_, "endStep");
+        try {
+            MagDate part1 = MagDate(day);
+            MagTime part2 = MagTime(hour, mn, 0);
+            DateTime full(part1, part2);
+            full = full + step;
 
-        MagDate part1 = MagDate(day);
-        MagTime part2 = MagTime(hour, mn, 0);
-        DateTime full(part1, part2);
-        full = full + step;
-
-        return full.tostring(format);
+            return full.tostring(format);
+        }
+        catch (MagicsException&) {
+            return "undef";
+        }
     }
 
-    void visit(const XmlNode& node) {
+    void visit(const XmlNode& node) override {
         if (magCompare(node.name(), "grib_info")) {
+           
             string grib  = node.getAttribute("id");
             string where = node.getAttribute("where");
+            
             if (!grib_.id(grib, where)) {
                 return;
             }
@@ -1314,7 +1354,10 @@ public:
             tree.visit(*this);
         }
         catch (MagicsException& e) {
-            MagLog::debug() << e.what() << endl;
+            if (MagicsGlobal::strict()) {
+                throw;
+            }
+            MagLog::error() << e.what() << endl;
         }
     }
     string str() const { return out.str(); }
@@ -1409,7 +1452,7 @@ void GribDecoder::visit(ValuesCollector& points) {
     double* y         = new double[nb];
     double* distances = new double[nb];
 
-    double scaling, offset;
+    double scaling = 1, offset = 0;
     string oriUnits, derivedUnits;
     string grid = representation();
 
@@ -1422,8 +1465,11 @@ void GribDecoder::visit(ValuesCollector& points) {
         interpretor_->scaling(*this, scaling, offset, oriUnits, derivedUnits);
     }
     catch (NoFactoryException&) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::warning() << "Grib Decoder: Representation [" << grid << "] not supported.\n" << std::endl;
-        ;
+
         scaling = 1;
         offset  = 0;
     }
@@ -1433,7 +1479,7 @@ void GribDecoder::visit(ValuesCollector& points) {
         inlons[i] = std::fmod(points[i].x(), 360.);
         if (inlons[i] < 0.)
             inlons[i] += 360.;
-        i++;
+        i++;  // FIXME: double increment
     }
 
     double missing = getDouble("missingValue");
@@ -1523,6 +1569,10 @@ void GribDecoder::ask(MetaDataCollector& meta) {
     }
 }
 
+string GribDecoder::getUnits() const {
+    return getString("units");
+}
+
 void GribDecoder::visit(MetaDataVisitor& meta) {
     if (!valid_)
         return;
@@ -1558,8 +1608,9 @@ string GribDecoder::representation() {
 }
 
 void GribDecoder::visit(MetaDataCollector& step) {
+
     // Here we gather information for the label!
-    const Transformation& transformation = step.transformation();
+    
 
     openField();  // just to be sure the file is opened!
 
@@ -1588,7 +1639,7 @@ void GribDecoder::visit(MetaDataCollector& step) {
                 // Compute stats
                 if (step.attribute(key->first).group() == MetaDataAttribute::StatsGroup) {
                     stats_.clear();
-
+                    const Transformation& transformation = step.transformation();
                     PointsHandler& points = this->points(transformation, false);
 
                     points.setToFirst();
@@ -1604,14 +1655,15 @@ void GribDecoder::visit(MetaDataCollector& step) {
                 else if (step.attribute(key->first).source() == MetaDataAttribute::AnySource ||
                          step.attribute(key->first).source() == MetaDataAttribute::GribApiSource) {
                     if (step.attribute(key->first).type() != MetaDataAttribute::NumberType) {
-                        need.push_back("<grib_info key='" + key->first + "'/>");
+                        need.push_back("<grib_info key='" + key->first + "' id='" + id_ + "'/>");  
                     }
                     else {
+
                         need.push_back("<grib_info key='" + key->first + "' readAsLong='yes'/>");
                     }
                 }
                 else if (key->first == "scaling_formula" || key->first == "scaled_units") {
-                    double scaling, offset;
+                    double scaling = 1, offset = 0;
                     string oriUnits, derivedUnits;
                     string grid = representation();
                     try {
@@ -1629,9 +1681,12 @@ void GribDecoder::visit(MetaDataCollector& step) {
                         }
                     }
                     catch (NoFactoryException&) {
+                        if (MagicsGlobal::strict()) {
+                            throw;
+                        }
                         MagLog::warning() << "Grib Decoder: Representation [" << grid << "] not supported.\n"
                                           << std::endl;
-                        ;
+
                         information_[key->first] = "N/A";
                     }
                 }
@@ -1664,24 +1719,31 @@ void GribDecoder::visit(MetaDataCollector& step) {
 
             if (members) {
                 name_ = helper.get("grib", "shortName") + " " + helper.get("grib", "level");
-
-                from_ = DateTime(helper.get("grib", "start-date"));
-                to_   = DateTime(helper.get("grib", "end-date"));
+                try {
+                    from_ = DateTime(helper.get("grib", "start-date"));
+                    to_   = DateTime(helper.get("grib", "end-date"));
+                }
+                catch (MagicsException& e) {
+                    MagLog::warning() << e.what() << std::endl;
+                }
             }
 
             for (map<string, string>::iterator key = step.begin(); key != step.end(); ++key) {
                 if (information_.find(key->first) == information_.end()) {
                     if (step.attribute(key->first).source() == MetaDataAttribute::AnySource ||
                         step.attribute(key->first).source() == MetaDataAttribute::GribApiSource) {
-                        key->second = helper.get("grib", key->first);
+                        key->second = helper.get("grib" + id_, key->first);
                         setInfo(key->first, key->second);
-                    }
+                     }
                 }
             }
         }
     }
 
     catch (...) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
     }
 }
 MatrixHandler& GribDecoder::direction() {
@@ -1713,6 +1775,8 @@ MatrixHandler& GribDecoder::direction() {
 
     return *(matrixHandlers_.back());
 }
+
+
 void GribDecoder::decode(const Transformation& transformation) {
     if (xComponent_ || !valid_)
         return;
@@ -1776,8 +1840,13 @@ void GribDecoder::decode() {
     name_    = helper.get("grib" + id_, "shortName") + "-" + helper.get("grib" + id_, "level");
     name_    = iconName_;
     layerId_ = name_ + file_name_;
-    from_    = DateTime(helper.get("grib" + id_, "start-date"));
-    to_      = DateTime(helper.get("grib" + id_, "end-date"));
+    try {
+        from_ = DateTime(helper.get("grib" + id_, "start-date"));
+        to_   = DateTime(helper.get("grib" + id_, "end-date"));
+    }
+    catch (MagicsException& e) {
+        MagLog::warning() << e.what() << std::endl;
+    }
 }
 
 void GribDecoder::visit(TextVisitor& title) {
@@ -1812,8 +1881,10 @@ void GribDecoder::decodeRaster(const Transformation& transformation) {
     }
 }
 
+
 void GribDecoder::initInfo() {
 #if defined(HAVE_METVIEW) && !defined(MAGICS_ON_WINDOWS)
+
     if (information_.find("_datatype") == information_.end()) {
         setInfo("_datatype", "GRIB");
 
@@ -1844,7 +1915,7 @@ class GribParameter : public GribInfo {
 public:
     GribParameter() {}
     ~GribParameter() {}
-    void operator()(ostream& out, const GribDecoder& grib) {
+    void operator()(ostream& out, const GribDecoder& grib) override {
         string val = grib.getString("name");
         out << val;
     }
@@ -1854,7 +1925,7 @@ class GribParamCriter : public MatchCriteria {
 public:
     GribParamCriter() {}
     ~GribParamCriter() {}
-    bool verify(const GribDecoder& grib, const string&, const string& val) {
+    bool verify(const GribDecoder& grib, const string&, const string& val) override {
         long param = grib.getLong("paramId");
         return (tostring(param) == val);
     }
@@ -1864,9 +1935,9 @@ class GribLocalCriter : public MatchCriteria {
 public:
     GribLocalCriter() {}
     ~GribLocalCriter() {}
-    bool verify(const GribDecoder& grib, const string& param, const string& val) {
+    bool verify(const GribDecoder& grib, const string& param, const string& val) override {
         string key    = param;
-        string criter = grib.getstring(key);
+        string criter = grib.getstring(key, false);
         MagLog::debug() << "I am verifing " << param << " for a GribDecoder : " << criter << " ==  " << val << "???"
                         << "\n";
         return (criter == val);
@@ -1877,7 +1948,7 @@ class GribObsDiagCriter : public MatchCriteria {
 public:
     GribObsDiagCriter() {}
     ~GribObsDiagCriter() {}
-    bool verify(const GribDecoder& grib, const string&, const string&) {
+    bool verify(const GribDecoder& grib, const string&, const string&) override {
         string param = grib.getstring("observationDiagnostic",
                                       false);  // do not warn if the key is absent
         return (param != "");
@@ -1889,11 +1960,12 @@ public:
     GribLocalDefHandler() {}
     ~GribLocalDefHandler() {}
 
-    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) {
+    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) override {
         ostringstream out;
         string local = grib.getstring("localDefinitionNumber");
         out << "local definition =" << local << " ";
         title.back() += out.str();
+        title.back() += " ";
     }
 };
 
@@ -1902,11 +1974,12 @@ public:
     GribObsDiagHandler() {}
     ~GribObsDiagHandler() {}
 
-    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) {
+    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) override {
         ostringstream out;
         string local = grib.getstring("observationDiagnostic");
         out << "diagnostic =" << local << " ";
         title.back() += out.str();
+        title.back() += " ";
     }
 };
 
@@ -1915,7 +1988,7 @@ public:
     GribObstatHandler() {}
     ~GribObstatHandler() {}
 
-    void operator()(TitleField&, vector<string>& /*title*/, const GribDecoder& grib) {}
+    void operator()(TitleField&, vector<string>& /*title*/, const GribDecoder& grib) override {}
 };
 
 class GribLocalHandler : public TitleFieldHandler {
@@ -1923,11 +1996,12 @@ public:
     GribLocalHandler(const string& local) : local_(local) {}
     ~GribLocalHandler() {}
 
-    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) {
+    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) override {
         ostringstream out;
         string code = grib.getstring(local_);
         out << local_ << "=" << code << " ";
         title.back() += out.str();
+        title.back() += " ";
     }
 
 protected:
@@ -1956,9 +2030,10 @@ class GribParamHandler : public TitleFieldHandler {
 public:
     GribParamHandler() {}
     ~GribParamHandler() {}
-    virtual void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) {
+    virtual void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) override {
         string param = grib.getString("name");
         title.back() += param;
+        title.back() += " ";
     }
 };
 
@@ -1966,7 +2041,7 @@ class GribKeyHandler : public TitleFieldHandler {
 public:
     GribKeyHandler() {}
     ~GribKeyHandler() {}
-    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) {
+    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) override {
         char x[256];
 
         string key    = field.attribute("key", "");
@@ -1975,6 +2050,7 @@ public:
         sprintf(x, format.c_str(), value.c_str());
 
         title.back() += string(x);
+        title.back() += " ";
     }
 };
 
@@ -1982,7 +2058,7 @@ class GribBaseDateHandler : public TitleFieldHandler {
 public:
     GribBaseDateHandler() {}
     ~GribBaseDateHandler() {}
-    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) {
+    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) override {
         ostringstream out;
 
         long date = grib.getLong("dataDate");
@@ -2003,6 +2079,7 @@ public:
         string format = field.attribute("format", "%A %d %B %Y at %H%M UTC");
 
         title.back() += full.tostring(format);
+        title.back() += " ";
     }
 };
 
@@ -2010,7 +2087,7 @@ class GribValidDateHandler : public TitleFieldHandler {
 public:
     GribValidDateHandler() {}
     ~GribValidDateHandler() {}
-    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) {
+    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) override {
         ostringstream out;
         long date = grib.getLong("dataDate");
         long hour = grib.getLong("hour");
@@ -2029,6 +2106,7 @@ public:
         string format = field.attribute("format", "%A %d %B %Y %H%M UTC");
 
         title.back() += full.tostring(format);
+        title.back() += " ";
     }
 };
 
@@ -2036,7 +2114,7 @@ class GribStepHandler : public TitleFieldHandler {
 public:
     GribStepHandler() {}
     ~GribStepHandler() {}
-    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) {
+    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) override {
         ostringstream out;
         long startstep = grib.getLong("startStep");
         long endstep   = grib.getLong("endStep");
@@ -2045,6 +2123,7 @@ public:
             ostringstream step;
             step << "from t+" << startstep << " to t+" << endstep;
             title.back() += step.str();
+            title.back() += " ";
             return;
         }
 
@@ -2053,6 +2132,7 @@ public:
         string format = field.attribute("format", "t+%s");
         out << SimpleStringFormat(step.str(), format);
         title.back() += out.str();
+        title.back() += " ";
     }
 };
 
@@ -2072,7 +2152,7 @@ public:
     ~GribLevelHandler() {}
     typedef string (GribLevelHandler::*Builder)(const string& def, const GribDecoder& grib) const;
 
-    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) {
+    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) override {
         ostringstream out;
 
         string level = grib.getstring("typeOfLevel");
@@ -2084,6 +2164,7 @@ public:
             out << level << " ";
 
         title.back() += out.str();
+        title.back() += " ";
     }
 
 protected:
@@ -2127,19 +2208,20 @@ class GribTimeHandler : public TitleFieldHandler {
 public:
     GribTimeHandler() {}
     ~GribTimeHandler() {}
-    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) { title.back() += "Time? "; }
+    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) override { title.back() += "Time? "; }
 };
 
 class GribCentreHandler : public TitleFieldHandler {
 public:
     GribCentreHandler() {}
     ~GribCentreHandler() {}
-    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) {
+    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) override {
         string format = field.attribute("format", "%s");
         string style  = field.attribute("style", "short");
         string centre = grib.getstring("centre");
 
         title.back() += centre;
+        title.back() += " ";
     }
 };
 
@@ -2147,7 +2229,7 @@ class GribProductHandler : public TitleFieldHandler {
 public:
     GribProductHandler() {}
     ~GribProductHandler() {}
-    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) {
+    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) override {
         long type = grib.getLong("type");
 
         // GeneralDef def = TypeTable::definition(type);
@@ -2159,21 +2241,21 @@ class GribPlotTypeHandler : public TitleFieldHandler {
 public:
     GribPlotTypeHandler() {}
     ~GribPlotTypeHandler() {}
-    void operator()(TitleField&, vector<string>&, const GribDecoder&) {}
+    void operator()(TitleField&, vector<string>&, const GribDecoder&) override {}
 };
 
 class NewLineHandler : public TitleFieldHandler {
 public:
     NewLineHandler() {}
     ~NewLineHandler() {}
-    void operator()(TitleField&, vector<string>& title, const GribDecoder&) { title.push_back(""); }
+    void operator()(TitleField&, vector<string>& title, const GribDecoder&) override { title.push_back(""); }
 };
 
 class SatelliteHandler : public TitleFieldHandler {
 public:
     SatelliteHandler() {}
     ~SatelliteHandler() {}
-    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) {
+    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) override {
         static map<long, string> names;
         if (names.empty()) {
             names[54]  = "METEOSAT-7";
@@ -2192,6 +2274,7 @@ public:
             title.back() += sat->second;
         else
             title.back() += "satellite identifier " + tostring(ident);
+        title.back() += " ";
     }
 };
 
@@ -2199,7 +2282,7 @@ class ChannelHandler : public TitleFieldHandler {
 public:
     ChannelHandler() {}
     ~ChannelHandler() {}
-    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) {
+    void operator()(TitleField&, vector<string>& title, const GribDecoder& grib) override {
         map<long, map<long, string> > channels;
         if (channels.empty()) {
             map<long, string> l54;
@@ -2254,19 +2337,23 @@ public:
         long ident = grib.getLong("ident");
         long band  = grib.getLong("channel");
 
+
         map<long, map<long, string> >::iterator sat = channels.find(ident);
 
         if (sat == channels.end()) {
             title.back() += "channel " + tostring(band);
+            title.back() += " ";
             return;
         }
         map<long, string>::iterator channel = sat->second.find(band);
         if (channel == sat->second.end()) {
             title.back() += "channel " + tostring(band);
+            title.back() += " ";
             return;
         }
 
         title.back() += channel->second;
+        title.back() += " ";
     }
 };
 
@@ -2274,9 +2361,10 @@ class GribExpverHandler : public TitleFieldHandler {
 public:
     GribExpverHandler() {}
     ~GribExpverHandler() {}
-    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) {
+    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) override {
         if (!grib.getExpver())
             return;
+        title.back() += " ";
         ostringstream out;
         string expver = grib.getstring("mars.experimentVersionNumber");
         string format = field.attribute("format", "Expver=%s");
@@ -2289,14 +2377,25 @@ class GribEpsNumberInfoHandler : public TitleFieldHandler {
 public:
     GribEpsNumberInfoHandler() {}
     ~GribEpsNumberInfoHandler() {}
-    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) { title.back() += "epsnumber?"; }
+    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) override {
+        title.back() += " ";
+        title.back() += "epsnumber?";
+    }
+};
+
+class GribIgnoreHandler : public TitleFieldHandler {
+public:
+    GribIgnoreHandler() {}
+    ~GribIgnoreHandler() {}
+    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) override {
+    }
 };
 
 class GribUnitHandler : public TitleFieldHandler {
 public:
     GribUnitHandler() {}
     ~GribUnitHandler() {}
-    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) {}
+    void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib) override {}
 };
 
 double GribDecoder::uComponent(int index) {
@@ -2340,6 +2439,7 @@ static SimpleObjectMaker<GribValidDateHandler, TitleFieldHandler> gribvaliddateh
 static SimpleObjectMaker<GribStepHandler, TitleFieldHandler> gribstephandler("step");
 static SimpleObjectMaker<GribEpsNumberInfoHandler, TitleFieldHandler> gribepsnumberhandler("eps_number_info");
 
+
 static SimpleObjectMaker<GribTimeHandler, TitleFieldHandler> gribTimehandler("time");
 static SimpleObjectMaker<GribLevelHandler, TitleFieldHandler> gribLevelhandler("level");
 static SimpleObjectMaker<NewLineHandler, TitleFieldHandler> newlinehandler("newline");
@@ -2357,6 +2457,7 @@ static SimpleObjectMaker<GribPlotTypeHandler, TitleFieldHandler> gribplottypehan
 static SimpleObjectMaker<SatelliteHandler, TitleFieldHandler> satellitehandler("satellite");
 static SimpleObjectMaker<ChannelHandler, TitleFieldHandler> channelhandler("channel");
 static SimpleObjectMaker<GribBaseDateHandler, TitleFieldHandler> datehandler("date");
+static SimpleObjectMaker<GribIgnoreHandler, TitleFieldHandler> texthandler("text");
 
 static SimpleObjectMaker<GribObsDiagCriter, MatchCriteria> gribobsdiagriter("observationDiagnostic");
 static SimpleObjectMaker<GribObsDiagHandler, TitleFieldHandler> gribobsdiaghandler("observationDiagnostic");
