@@ -50,7 +50,7 @@ string TileDecoder::weights() {
     ostringstream out;
     string parent = getEnvVariable("MAGPLUS_TILE");
     if (parent.empty()) {
-        parent = getEnvVariable("MAGPLUS_HOME") + "/share/magics/tiles";
+        parent = buildSharePath("tiles");
     }
     out << parent << "/weight-" << grid_ << "-" << projection() << "-z" + tostring(z_) << ".nc";
     return out.str();
@@ -60,7 +60,7 @@ string TileDecoder::positions() {
     ostringstream out;
     string parent = getEnvVariable("MAGPLUS_TILE");
     if (parent.empty()) {
-        parent = getEnvVariable("MAGPLUS_HOME") + "/share/magics/tiles";
+        parent = buildSharePath("tiles");
     }
     out << parent << "/wind-" << grid_ << "-" << projection() << "-z" + tostring(z_) << ".nc";
 
@@ -71,7 +71,7 @@ string TileDecoder::positions_symbols() {
     ostringstream out;
     string parent = getEnvVariable("MAGPLUS_TILE");
     if (parent.empty()) {
-        parent = getEnvVariable("MAGPLUS_HOME") + "/share/magics/tiles";
+        parent = buildSharePath("tiles");
     }
     out << parent << "/symbol-" << grid_ << "-" << projection() << "-z" + tostring(z_) << ".nc";
     file_ = ifstream(out.str());
@@ -84,8 +84,11 @@ string TileDecoder::positions_symbols() {
 }
 
 bool TileDecoder::ok() {
-    FILE* in = fopen(file_name_.c_str(), "r");
+    FILE* in = fopen(file_name_.c_str(), "rb");
     if (!in) {
+        if (MagicsGlobal::strict()) {
+            throw CannotOpenFile(file_name_);
+        }
         MagLog::error() << "ERROR: unable to open file" << file_name_ << endl;
         return false;
     }
@@ -163,8 +166,11 @@ void TileDecoder::customisedPoints(const Transformation& transformation, const s
 
     int error;
 
-    FILE* in = fopen(file_name_.c_str(), "r");
+    FILE* in = fopen(file_name_.c_str(), "rb");
     if (!in) {
+        if (MagicsGlobal::strict()) {
+            throw CannotOpenFile(file_name_);
+        }
         MagLog::error() << "ERROR: unable to open file" << file_name_ << endl;
         return;
     }
@@ -255,8 +261,11 @@ PointsHandler& TileDecoder::points(const Transformation& t, bool) {
 
     int error;
 
-    FILE* in = fopen(file_name_.c_str(), "r");
+    FILE* in = fopen(file_name_.c_str(), "rb");
     if (!in) {
+        if (MagicsGlobal::strict()) {
+            throw CannotOpenFile(file_name_);
+        }
         MagLog::error() << "ERROR: unable to open file" << file_name_ << endl;
         pointsHandlers_.push_back(new PointsHandler(points_));
         return *(pointsHandlers_.back());
@@ -323,6 +332,7 @@ PointsHandler& TileDecoder::points(const Transformation& t, bool) {
     return *(pointsHandlers_.back());
 #else
     MagLog::warning() << " TileDecoder> Can NOT work because NetCDF was DISABLED in Magics!" << endl;
+    NOTIMP;
 #endif
 }
 
@@ -447,8 +457,11 @@ void TileDecoder::decode() {
         netcdf.get("bounding-box", bbox, first, last);
 
         int error;
-        FILE* in = fopen(file_name_.c_str(), "r");
+        FILE* in = fopen(file_name_.c_str(), "rb");
         if (!in) {
+            if (MagicsGlobal::strict()) {
+                throw CannotOpenFile(file_name_);
+            }
             MagLog::error() << "ERROR: unable to create handle from file" << file_name_ << endl;
             return;
         }
