@@ -24,6 +24,8 @@
 #include "MagException.h"
 #include "TitleMetaField.h"
 #include "TitleStringField.h"
+#include "MagicsGlobal.h"
+
 #include "expat.h"
 using namespace magics;
 
@@ -93,7 +95,7 @@ TitleTemplate::TitleTemplate() {
 
 void TitleTemplate::decode() {
     singleton_      = this;
-    string filename = buildConfigPath(file_);
+    string filename = buildSharePath(file_);
     char buf[BUFSIZ];
     ignore_space_ = true;
     push(this);
@@ -106,8 +108,9 @@ void TitleTemplate::decode() {
 
     FILE* in = fopen(filename.c_str(), "r");
 
-    if (!in)
+    if (!in) {
         throw CannotOpenFile(filename);
+    }
 
     do {
         size_t len = fread(buf, 1, sizeof(buf), in);
@@ -145,7 +148,6 @@ void TitleTemplate::print(ostream& out) const {
 
 bool TitleTemplate::verify(const GribDecoder& data) const {
     for (map<string, string>::const_iterator criter = criteria_.begin(); criter != criteria_.end(); ++criter) {
-
         try {
             MagLog::debug() << "Try  to create the MatchCriteria for " << criter->first << "\n";
             unique_ptr<MatchCriteria> object(SimpleObjectMaker<MatchCriteria>::create(criter->first));
@@ -154,6 +156,9 @@ bool TitleTemplate::verify(const GribDecoder& data) const {
                 return false;
         }
         catch (NoFactoryException& e) {  // The data do not know how to verify the criter ....
+            if (MagicsGlobal::strict()) {
+                throw;
+            }
             MagLog::warning() << "Can Not Create the MatchCriteria for " << criter->first << "\n";
             return false;
         }
