@@ -19,9 +19,9 @@
 #ifndef _MPP_BinaryDriver_H
 #define _MPP_BinaryDriver_H
 
-#include <BaseDriver.h>
-#include <BinaryDriverAttributes.h>
-#include <XmlNode.h>
+#include "BaseDriver.h"
+#include "BinaryDriverAttributes.h"
+#include "XmlNode.h"
 
 namespace magics {
 
@@ -34,14 +34,14 @@ namespace magics {
 class BinaryDriver : public BaseDriver, public BinaryDriverAttributes {
 public:
     BinaryDriver();
-    ~BinaryDriver();
-    void open();
-    void close();
+    ~BinaryDriver() override;
+    void open() override;
+    void close() override;
 
     /*!
       \brief sets a new XML node
     */
-    void set(const XmlNode& node) {
+    void set(const XmlNode& node) override {
         if (magCompare(node.name(), "mgb")) {
             XmlNode basic = node;
             basic.name("driver");
@@ -54,47 +54,47 @@ public:
     /*!
       \brief sets a new map
     */
-    void set(const map<std::string, std::string>& map) {
+    void set(const map<std::string, std::string>& map) override {
         BaseDriver::set(map);
         BinaryDriverAttributes::set(map);
     }
 
 private:
-    MAGICS_NO_EXPORT void startPage() const;
-    MAGICS_NO_EXPORT void endPage() const;
-    MAGICS_NO_EXPORT void project(const Layout& lay) const;
-    MAGICS_NO_EXPORT void unproject() const;
+    MAGICS_NO_EXPORT void startPage() const override;
+    MAGICS_NO_EXPORT void endPage() const override;
+    MAGICS_NO_EXPORT void project(const Layout& lay) const override;
+    MAGICS_NO_EXPORT void unproject() const override;
 
-    MAGICS_NO_EXPORT void setNewLineWidth(const MFloat) const;
-    MAGICS_NO_EXPORT void setNewColour(const Colour& col) const;
-    MAGICS_NO_EXPORT int setLineParameters(const LineStyle style, const MFloat w) const;
+    MAGICS_NO_EXPORT void setNewLineWidth(const MFloat) const override;
+    MAGICS_NO_EXPORT void setNewColour(const Colour& col) const override;
+    MAGICS_NO_EXPORT void setLineParameters(const LineStyle style, const MFloat w) const override;
 
-    MAGICS_NO_EXPORT void renderPolyline(const int, MFloat*, MFloat*) const;
-    MAGICS_NO_EXPORT void renderPolyline2(const int n, MFloat* x, MFloat* y) const;
-    MAGICS_NO_EXPORT void renderSimplePolygon(const int, MFloat*, MFloat*) const;
-    MAGICS_NO_EXPORT void renderSimplePolygon(const Polyline& line) const;
-    MAGICS_NO_EXPORT void renderText(const Text& text) const;
-    MAGICS_NO_EXPORT void circle(const MFloat x, const MFloat y, const MFloat r, const int) const;
+    MAGICS_NO_EXPORT void renderPolyline(const int, MFloat*, MFloat*) const override;
+    MAGICS_NO_EXPORT void renderPolyline2(const int n, MFloat* x, MFloat* y) const override;
+    MAGICS_NO_EXPORT void renderSimplePolygon(const int, MFloat*, MFloat*) const override;
+    MAGICS_NO_EXPORT void renderSimplePolygon(const Polyline& line) const override;
+    MAGICS_NO_EXPORT void renderText(const Text& text) const override;
+    MAGICS_NO_EXPORT void circle(const MFloat x, const MFloat y, const MFloat r, const int) const override;
+    MAGICS_NO_EXPORT bool renderPixmap(MFloat, MFloat, MFloat, MFloat, int, int, unsigned char*, int, bool, bool) const override;
+    MAGICS_NO_EXPORT bool renderCellArray(const Image& obj) const override;
     MAGICS_NO_EXPORT void renderImage(const ImportObject& obj) const;
-    MAGICS_NO_EXPORT bool renderPixmap(MFloat, MFloat, MFloat, MFloat, int, int, unsigned char*, int, bool, bool) const;
-    MAGICS_NO_EXPORT bool renderCellArray(const Image& obj) const;
 
     // BinaryDriver specific member functions BEGIN
-    MAGICS_NO_EXPORT void renderWindArrow(const Arrow& arrow) const;
-    MAGICS_NO_EXPORT void renderWindFlag(const Flag& flag) const;
+    MAGICS_NO_EXPORT void renderWindArrow(const Arrow& arrow) const override;
+    MAGICS_NO_EXPORT void renderWindFlag(const Flag& flag) const override;
 
-    MAGICS_NO_EXPORT MFloat setAngleY(const MFloat y) const { return -y; }
-    MAGICS_NO_EXPORT MFloat setSymbolY(const MFloat y) const { return -y; }
-    MAGICS_NO_EXPORT MFloat setFlagY(const MFloat y) const { return y; }
-    MAGICS_NO_EXPORT MFloat setY(const MFloat y) const { return y; }
+    MAGICS_NO_EXPORT MFloat setAngleY(const MFloat y) const override { return -y; }
+    MAGICS_NO_EXPORT MFloat setSymbolY(const MFloat y) const override { return -y; }
+    MAGICS_NO_EXPORT MFloat setFlagY(const MFloat y) const override { return y; }
+    MAGICS_NO_EXPORT MFloat setY(const MFloat y) const override { return y; }
 
     mutable ofstream out_;
 
     // BinaryDriver specific member functions END
 
     //! Method to print string about this class on to a stream of type ostream (virtual).
-    void print(ostream&) const;
-    MAGICS_NO_EXPORT void debugOutput(const string& s) const { MagLog::debug() << s << endl; }
+    void print(ostream&) const override;
+    MAGICS_NO_EXPORT void debugOutput(const string& s) const override { MagLog::debug() << s << endl; }
 
     //! Copy constructor - No copy allowed
     BinaryDriver(const BinaryDriver&);
