@@ -37,15 +37,15 @@ Something like:
 */
 #include <cairo.h>
 
-#include <CairoDriver.h>
+#include "CairoDriver.h"
 
-#include <Image.h>
-#include <ImportObject.h>
-#include <Polyline.h>
-#include <Symbol.h>
-#include <System.h>
-#include <Text.h>
-#include <Timer.h>
+#include "Image.h"
+#include "ImportObject.h"
+#include "Polyline.h"
+#include "Symbol.h"
+#include "System.h"
+#include "Text.h"
+#include "Timer.h"
 
 #include <iconv.h>  // Only for AIX?
 #include <pango/pangocairo.h>
@@ -127,7 +127,14 @@ void CairoDriver::setupNewSurface() const {
 #if CAIRO_HAS_PDF_SURFACE
         fileName_ = getFileName("pdf");
         surface_  = cairo_pdf_surface_create(fileName_.c_str(), dimensionXglobal_, dimensionYglobal_);
-
+#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 16, 0)
+        cairo_pdf_surface_set_metadata(surface_, CAIRO_PDF_METADATA_TITLE, title_.c_str());
+        const SystemInfo info;
+        cairo_pdf_surface_set_metadata(surface_, CAIRO_PDF_METADATA_AUTHOR, info.getUserID().c_str());
+        const string creator = output_creator_ + " " + getMagicsVersionString();
+        cairo_pdf_surface_set_metadata(surface_, CAIRO_PDF_METADATA_CREATOR, creator.c_str());
+//        cairo_pdf_surface_set_metadata(surface_, CAIRO_PDF_METADATA_KEYWORDS, <string with tags for Intraplots>;        
+#endif
 #else
         MagLog::error() << "CairoDriver: PDF output NOT supported! Enable PDF support in your Cairo installation."
                         << std::endl;
@@ -378,12 +385,18 @@ MAGICS_NO_EXPORT void CairoDriver::write_tiff() const {
 
     TIFF* tif = TIFFOpen(fileName_.c_str(), "w");
     if (!tif) {
+        if (MagicsGlobal::strict()) {
+            throw CannotOpenFile(fileName_);
+        }
         MagLog::warning() << "CairoDriver: Unable to open TIFF file " << fileName_ << std::endl;
         return;
     }
 
     GTIF* gtif = GTIFNew(tif);
     if (!gtif) {
+        if (MagicsGlobal::strict()) {
+            throw CannotOpenFile(fileName_);
+        }
         MagLog::warning() << "CairoDriver: Unable to open GeoTIFF file " << fileName_ << std::endl;
         return;
     }
@@ -573,34 +586,34 @@ MAGICS_NO_EXPORT void CairoDriver::setNewLineWidth(const MFloat width) const {
   \param linestyle Object describing the line style
   \param width width of the line
 */
-MAGICS_NO_EXPORT int CairoDriver::setLineParameters(const LineStyle linestyle, const MFloat width) const {
+MAGICS_NO_EXPORT void CairoDriver::setLineParameters(const LineStyle linestyle, const MFloat width) const {
     setNewLineWidth(width);
 
 #if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 4, 0)
-    if (cairo_get_dash_count(cr_) == 0 && linestyle == M_SOLID)
-        return 0;
+    if (cairo_get_dash_count(cr_) == 0 && linestyle == LineStyle::SOLID)
+        return;
 #endif
     switch (linestyle) {
-        case M_DASH:  // 6 on - 2 off
+        case LineStyle::DASH:  // 6 on - 2 off
         {
             cairo_set_line_cap(cr_, CAIRO_LINE_CAP_SQUARE);
             const double dash_line[] = {4.};
             cairo_set_dash(cr_, dash_line, 1, 0.);
         } break;
-        case M_DOT:  // 1 on - 2 off
+        case LineStyle::DOT:  // 1 on - 2 off
         {
             setNewLineWidth(2 * width);
             const double dotted_line[] = {0., 6.};
             cairo_set_line_cap(cr_, CAIRO_LINE_CAP_ROUND);
             cairo_set_dash(cr_, dotted_line, 2, 0.);
         } break;
-        case M_CHAIN_DASH:  // 4 on - 2 off -  1 on - 2 off
+        case LineStyle::CHAIN_DASH:  // 4 on - 2 off -  1 on - 2 off
         {
             const double chain_dash_line[] = {4., 4., 0., 6.};
             cairo_set_line_cap(cr_, CAIRO_LINE_CAP_SQUARE);
             cairo_set_dash(cr_, chain_dash_line, 4, 0.);
         } break;
-        case M_CHAIN_DOT:  // 4 on - 2 off -  1 on - 2 off - 1 on - 2 off
+        case LineStyle::CHAIN_DOT:  // 4 on - 2 off -  1 on - 2 off - 1 on - 2 off
         {
             const double chain_dot_line[] = {4., 4., 0., 6., 0., 6.};
             cairo_set_line_cap(cr_, CAIRO_LINE_CAP_SQUARE);
@@ -613,7 +626,6 @@ MAGICS_NO_EXPORT int CairoDriver::setLineParameters(const LineStyle linestyle, c
             cairo_set_dash(cr_, solid_line, 0, 0.);
         } break;
     }
-    return 0;
 }
 
 /*!
@@ -786,7 +798,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderSimplePolygon(const int n, MFloat* x, M
 */
 MAGICS_NO_EXPORT void CairoDriver::renderSimplePolygon() const {
 #if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 2, 0)
-    if (currentShading_ == M_SH_DOT) {
+    if (currentShading_ == Shading::DOT) {
         const DotShadingProperties* pro = (DotShadingProperties*)currentShadingProperties_;
         const int density               = (int)sqrt(pro->density_);
         if (density <= 0)
@@ -819,7 +831,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderSimplePolygon() const {
         cairo_surface_destroy(pat_surface);
         cairo_destroy(cr2);
     }
-    else if (currentShading_ == M_SH_HATCH) {
+    else if (currentShading_ == Shading::HATCH) {
         const HatchShadingProperties* pro = (HatchShadingProperties*)currentShadingProperties_;
         indexHatch_                       = pro->index_;
         if (indexHatch_ < 1 || indexHatch_ > 6) {
@@ -874,7 +886,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderSimplePolygon() const {
     }
     else
 #else
-    if (currentShading_ == M_SH_HATCH || currentShading_ == M_SH_DOT)
+    if (currentShading_ == Shading::HATCH || currentShading_ == Shading::DOT)
         MagLog::error() << "CairoDriver: For hatch and dot shading you need at least Cairo 1.2!\n"
                         << "             Solid shading used instead." << std::endl;
 #endif
@@ -882,7 +894,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderSimplePolygon() const {
         cairo_fill(cr_);
     }
     cairo_restore(cr_);
-    currentShading_ = M_SH_SOLID;
+    currentShading_ = Shading::SOLID;
 }
 
 
@@ -944,7 +956,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderText(const Text& text) const {
             gchar* t = g_markup_escape_text((*niceText).text().c_str(), -1);
 
             alltext << "<span color=\"" << col.str() << "\" font_family=\"" << magfont.name() << "\" size=\""
-                    << int(magfont.size() * FONT_SCALE * 1024) << "\"";
+                    << int(magfont.size() * FONT_SCALE * 1024 * font_scale_) << "\"";
             if (styles.find("bold") != styles.end())
                 alltext << " weight=\"bold\"";
             else if (styles.find("italic") != styles.end())
@@ -1005,19 +1017,19 @@ MAGICS_NO_EXPORT void CairoDriver::renderText(const Text& text) const {
         double height = h / PANGO_SCALE;
 
         MFloat x = 0;
-        if (horizontal == MCENTRE)
+        if (horizontal == Justification::CENTRE)
             x = width * .5;
-        else if (horizontal == MRIGHT)
+        else if (horizontal == Justification::RIGHT)
             x = width;
 
         MFloat y = 0.;
-        if (vertical == MBASE) {
+        if (vertical == VerticalAlign::BASE) {
             y = height * .85;
         }
-        else if (vertical == MHALF) {
+        else if (vertical == VerticalAlign::HALF) {
             y = height * .5;
         }
-        else if (vertical == MBOTTOM) {
+        else if (vertical == VerticalAlign::BOTTOM) {
             y = height;
         }
 
@@ -1322,11 +1334,11 @@ MAGICS_NO_EXPORT void CairoDriver::renderSymbols(const Symbol& symbol) const {
     else {
         string logofile;
         if (symbolName == "logo_cams")
-            logofile = buildConfigPath("CAMS_combined.png");
+            logofile = buildSharePath("CAMS_combined.png");
         else if (symbolName == "logo_c3s")
-            logofile = buildConfigPath("C3S_combined.png");
+            logofile = buildSharePath("C3S_combined.png");
         else
-            logofile = buildConfigPath("ecmwf_logo_2014.png");
+            logofile = buildSharePath("ecmwf_logo_2014.png");
 
         cairo_surface_t* image = cairo_image_surface_create_from_png(logofile.c_str());
         cairo_status_t ret     = cairo_surface_status(image);
@@ -1353,7 +1365,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderSymbols(const Symbol& symbol) const {
 MAGICS_NO_EXPORT bool CairoDriver::convertToPixmap(const string& fname, const GraphicsFormat format, const int reso,
                                                    const MFloat wx0, const MFloat wy0, const MFloat wx1,
                                                    const MFloat wy1) const {
-    if (format == PNG) {
+    if (format == GraphicsFormat::PNG) {
         cairo_save(cr_);
         cairo_surface_t* image = cairo_image_surface_create_from_png(fname.c_str());
         int w                  = cairo_image_surface_get_width(image);
