@@ -25,6 +25,7 @@
 #include "Symbol.h"
 #include "Transformation.h"
 #include "expat.h"
+#include "MagicsGlobal.h"
 
 #include "ProgressObject.h"
 
@@ -49,7 +50,7 @@ ObsTable* ObsTable::table_ = 0;
 
 
 ObsTable::ObsTable() {
-    string filename = path_.empty() ? buildConfigPath("obs.xml") : path_;
+    string filename = path_.empty() ? buildSharePath("obs.xml") : path_;
     char buf[BUFSIZ];
     XML_Parser parser = XML_ParserCreate(NULL);
     int done;
@@ -59,8 +60,9 @@ ObsTable::ObsTable() {
     // FMagLog::dev() << "Load observation templates --->" << filename << endl;
     FILE* in = fopen(filename.c_str(), "r");
 
-    if (!in)
+    if (!in) {
         throw CannotOpenFile(filename);
+    }
 
     do {
         size_t len = fread(buf, 1, sizeof(buf), in);
@@ -107,6 +109,9 @@ void ObsTable::add(const string& tag, const map<string, string>& def) {
             current_->push_back(obs);
         }
         catch (NoFactoryException&) {
+            if (MagicsGlobal::strict()) {
+                throw;
+            }
             // FMagLog::dev() << "can not find ObsItem for : " << tag << "\n";
             cout << "can not find ObsItem for : " << tag << "\n";
         }
