@@ -13,12 +13,12 @@
 #include "CustomisedPoint.h"
 #include "EfiLegendEntry.h"
 #include "IntervalMap.h"
+#include "JSON.h"
 #include "MagException.h"
+#include "MagParser.h"
 #include "MetaData.h"
 #include "TextVisitor.h"
 #include "Value.h"
-#include "JSONParser.h"
-#include "JSON.h"
 
 using namespace magics;
 
@@ -1009,7 +1009,7 @@ void WrepJSon::basic() {
 
 
     try {
-        Value value = JSONParser::decodeFile(file_);
+        Value value     = MagParser::decodeFile(file_);
         ValueMap object = value.get_value<ValueMap>();
 
         for (auto entry = object.begin(); entry != object.end(); ++entry) {
@@ -1022,6 +1022,9 @@ void WrepJSon::basic() {
         }
     }
     catch (std::exception& e) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::error() << "Could not processed the file: " << file_ << ": " << e.what() << endl;
         // abort();
     }
@@ -1081,6 +1084,9 @@ void WrepJSon::height(const Value& value) {
         height_ = value.get_value<double>();
     }
     catch (...) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::dev() << "ognore" << height_ << endl;
     }
 }
@@ -1124,7 +1130,7 @@ void WrepJSon::clim_step(const Value& value) {
 }
 
 void WrepJSon::time(const Value& value) {
-    
+
     MagLog::dev() << "found -> time= " << value.get_value<string>() << endl;
     time_ = value.get_value<string>();
 }
@@ -1875,3 +1881,7 @@ PointsHandler& WrepJSon::points(const Transformation& transformation, bool) {
     pointsHandlers_.push_back(new PointsHandler(list_));
     return *pointsHandlers_.back();
 }
+
+std::string WrepJSon::getUnits() const {
+    return "";
+}
